package recipe

import (
	"github.com/urfave/cli/v2"
)

var Major bool
var MajorFlag = &cli.BoolFlag{
	Name:        "major",
	Usage:       "Increase the major part of the version (new functionality, backwards incompatible, x of x.y.z)",
	Value:       false,
	Aliases:     []string{"ma", "x"},
	Destination: &Major,
}

var Minor bool
var MinorFlag = &cli.BoolFlag{
	Name:        "minor",
	Usage:       "Increase the minor part of the version (new functionality, backwards compatible, y of x.y.z)",
	Value:       false,
	Aliases:     []string{"mi", "y"},
	Destination: &Minor,
}

var Patch bool
var PatchFlag = &cli.BoolFlag{
	Name:        "patch",
	Usage:       "Increase the patch part of the version (bug fixes, backwards compatible, z of x.y.z)",
	Value:       false,
	Aliases:     []string{"p", "z"},
	Destination: &Patch,
}

// RecipeCommand defines all recipe related sub-commands.
var RecipeCommand = &cli.Command{
	Name:      "recipe",
	Usage:     "Manage recipes (for maintainers)",
	ArgsUsage: "<recipe>",
	Aliases:   []string{"r"},
	Description: `
A recipe is a blueprint for an app. It is a bunch of configuration files which
describe how to deploy and maintain an app. Recipes are maintained by the Co-op
Cloud community and you can use Abra to read them and create apps for you.
`,
	Subcommands: []*cli.Command{
		recipeListCommand,
		recipeVersionCommand,
		recipeReleaseCommand,
		recipeNewCommand,
		recipeUpgradeCommand,
		recipeSyncCommand,
		recipeLintCommand,
	},
}
